@@ -253,13 +253,14 @@ class Manifest:
         ):
             raise ValueError("workspace_id must be a non-empty string")
 
-        if (
-            self._ignore_path is not None
-            and
-            not os.path.isdir(self._ignore_path)
-        ):
-            raise ValueError(
-                "ignore_path_prefix must be a directory if provided")
+        # TODO:  Make code below work properly when creating db from json.
+        # if (
+        #     self._ignore_path is not None
+        #     and
+        #     not os.path.isdir(self._ignore_path)
+        # ):
+        #     raise ValueError(
+        #         "ignore_path_prefix must be a directory if provided")
 
         if (
             not self._hyperthought_root
@@ -764,20 +765,73 @@ def from_json(manifest_data: Dict, manifest_database_file: str) -> Manifest:
     )
 
     # Add files to the manifest.
-    json_id_to_database_id = {}
+    manifest_files = sorted(
+        manifest_data["files"],
+        key=lambda item: item["path"],
+    )
+    len_ignore_path = len(manifest.ignore_path)
+    path_to_hyperthought_id = {}
+    manifest_id_to_hyperthought_id = {}
+    file_data = []
 
-    for file_ in manifest_data["files"]:
-        path = file_["path"]
-        manifest.add_path(path=path)
-        json_id = file_["id"]
-        database_id = manifest.get_path_id(path=path)
-        json_id_to_database_id[json_id] = database_id
+    for manifest_file in manifest_files:
+        path = utils.clean_path(manifest_file["path"])
+        relative_path = path[len_ignore_path:].replace("\\", "/").strip("/")
+        hyperthought_id = utils.generate_id()
+        manifest_id_to_hyperthought_id[manifest_file["id"]] = hyperthought_id
+        path_to_hyperthought_id[relative_path] = hyperthought_id
+        is_folder = manifest_file["type"] == "folder"
+
+        if not is_folder:
+            end_bytes = ",".join(str(i) for i in manifest_file["endBytes"])
+        else:
+            end_bytes = None
+
+        path_tokens = relative_path.split("/")
+        hyperthought_id_path = manifest.hyperthought_root_id_path
+
+        for index in range(0, len(path_tokens) - 1):
+            parent_path = "/".join(path_tokens[:(index + 1)])
+
+            if parent_path not in path_to_hyperthought_id:
+                full_parent_path = f"{manifest.ignore_path}/{parent_path}"
+                raise ValueError(f"missing parent path: {full_parent_path}")
+
+            parent_id = path_to_hyperthought_id[parent_path]
+            hyperthought_id_path = f"{hyperthought_id_path}{parent_id},"
+
+        # TODO:  Add validation for manifest data:  size, hash.
+
+        file_data.append({
+            "name": os.path.basename(relative_path),
+            "hyperthought_id": hyperthought_id,
+            "hyperthought_id_path": hyperthought_id_path,
+            "is_folder": is_folder,
+            "path": path,
+            "end_bytes": end_bytes,
+            "size": manifest_file["size"],
+            "file_hash": manifest_file["hash"],
+        })
+
+    with open("D:/work/bugs/IC-7317/debug.json", "w") as f:
+        import json
+        json.dump(file_data, f, indent=2)
+
+    manifest.database.bulk_load_files(file_data=file_data)
+    ht_to_db_id = {
+        item["hyperthought_id"]: item["id"]
+        for item in file_data
+    }
+    manifest_id_to_database_id = {
+        manifest_id: ht_to_db_id[manifest_id_to_hyperthought_id[manifest_id]]
+        for manifest_id in manifest_id_to_hyperthought_id
+    }
 
     # Add parsers to the manifest.
     for parser in manifest_data["metadata"]["parsing"]:
-        file_id = json_id_to_database_id[parser["parseFileId"]]
+        file_id = manifest_id_to_database_id[parser["parseFileId"]]
         apply_to_file_ids = [
-            json_id_to_database_id[id_] for id_ in parser["applyToFileIds"]
+            manifest_id_to_database_id[id_] for id_ in parser["applyToFileIds"]
         ]
         manifest.add_parser(
             file_id=file_id,
@@ -790,7 +844,7 @@ def from_json(manifest_data: Dict, manifest_database_file: str) -> Manifest:
         metadata = ht.metadata.from_api_format(
             metadata=metadata_item["metadata"])
         apply_to_file_ids = [
-            json_id_to_database_id[id_]
+            manifest_id_to_database_id[id_]
             for id_ in metadata_item["applyToFileIds"]
         ]
         manifest.add_metadata(
