@@ -12,7 +12,7 @@ from typing import Optional
 import hyperthought as ht
 from hyperthought.metadata import MetadataItem
 
-from . import connect, template
+from . import connect, template  # noqa: F401
 
 
 class FileStatus(IntEnum):
@@ -598,11 +598,49 @@ class Database:
 
         return all_metadata
 
-    def get_file(self, file_id: int) -> Optional[Dict]:
-        """Get a file record from a file id."""
-        sql = "SELECT * FROM File WHERE id = :file_id"
+    def get_file(
+        self,
+        file_id: Optional[int] = None,
+        name: Optional[str] = None,
+        hyperthought_id_path: Optional[str] = None,
+    ) -> Optional[Dict]:
+        """
+        Get a file/folder record given identifying information.
+
+        Parameters
+        ----------
+        file_id : int or None
+            The database id for the file/folder.
+        name: str or None
+            The name of the file/folder.
+        hyperthought_id_path: str or None
+            Comma-separated parent folder ids, e.g. ",uuid,uuid,uuid,".
+
+        Either file_id or name and hyperthought_id must be provided.
+        """
+        if file_id is None and (name is None or hyperthought_id_path) is None:
+            raise ValueError(
+                "file_id or name and hyperthought_id_path must be provided")
+
         cursor = self.connection.cursor()
-        cursor.execute(sql, {"file_id": file_id})
+
+        if file_id:
+            sql = "SELECT * FROM File WHERE id = :file_id"
+            cursor.execute(sql, {"file_id": file_id})
+        else:
+            sql = """
+            SELECT *
+            FROM File
+            WHERE
+                name = :name
+                AND
+                hyperthought_id_path = :hyperthought_id_path
+            """
+            cursor.execute(sql, {
+                "name": name,
+                "hyperthought_id_path": hyperthought_id_path,
+            })
+
         row = cursor.fetchone()
 
         if not row:
@@ -1195,4 +1233,3 @@ class Database:
         )
         row = cursor.fetchone()
         return bool(row["error_count"])
-
